@@ -6,7 +6,9 @@
 #' This function is a user-friendly wrapper for \code{RoundViaDummy} with data frame output and with computed summary of the results.
 #' See \code{\link{RoundViaDummy}} for more details.
 #'
-#' @param data Input data as a data frame (inner cells)
+#' @param data Input data (inner cells), typically a data frame, tibble, or data.table. 
+#'             If `data` is not a classic data frame, it will be coerced to one internally 
+#'             unless `preAggregate` is `TRUE` and `aggregatePackage` is `"data.table"`.
 #' @param freqVar Variable holding counts (inner cells frequencies).  When \code{NULL} (default), microdata is assumed.
 #' @param roundBase Rounding base
 #' @param hierarchies List of hierarchies
@@ -83,9 +85,8 @@
 #' mean(abs(a$publish[, "difference"]))
 #' sqrt(mean((a$publish[, "difference"])^2))
 #' 
-#' # Six lines below produce equivalent results 
+#' # Five lines below produce equivalent results 
 #' # Ordering of rows can be different
-#' PLSrounding(z, "freq") # All variables except "freq" as dimVar  
 #' PLSrounding(z, "freq", dimVar = c("geo", "eu", "year"))
 #' PLSrounding(z, "freq", formula = ~eu * year + geo * year)
 #' PLSrounding(z[, -2], "freq", hierarchies = SmallCountData("eHrc"))
@@ -141,6 +142,14 @@
 #' PLS2way(a)  # Values in col1 rounded
 #' a <- PLSrounding(exPSD, "freq", 5, formula = ~rows + cols, zeroCandidates = TRUE)
 #' PLS2way(a)  # (row3, col4): original is 0 and rounded is 5
+#' 
+#' # Using formula followed by FormulaSelection 
+#' output <- PLSrounding(data = SmallCountData("example1"), 
+#'                       formula = ~age * geo * year + eu * year, 
+#'                       freqVar = "freq", 
+#'                       roundBase = 5)
+#' FormulaSelection(output, ~(age + eu) * year)
+#' 
 PLSrounding <- function(data, freqVar = NULL, roundBase = 3, hierarchies = NULL, formula = NULL, 
                         dimVar = NULL,
                         maxRound = roundBase-1, printInc = nrow(data)>1000, 
@@ -156,6 +165,16 @@ PLSrounding <- function(data, freqVar = NULL, roundBase = 3, hierarchies = NULL,
   
   force(preAggregate)
   
+  if (!hasArg("x")) {
+    if (is.null(dimVar) & is.null(hierarchies) & is.null(formula)) {
+      stop("dimVar, hierarchies or formula must be specified")
+    }
+  }
+  
+  if (!(preAggregate & aggregatePackage == "data.table")) {
+    data <- as.data.frame(data)
+  }
+  
   names_data <- names(data)
   
   if(!is.null(output)){
